==> seedsui-react-5.6.60.tgz: package/lib/InputStar/InputStar.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["min", "max", "value", "onChange", "onError"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useContext } from 'react';
import Star from "./../Star";
import Context from "../Context/instance.js";

/**
 * @deprecated since version 5.2.8
 * 请使用Input.Star
 */
import { jsx as _jsx } from "react/jsx-runtime";
var InputStar = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$min = _ref.min,
    min = _ref$min === void 0 ? 0 : _ref$min,
    _ref$max = _ref.max,
    max = _ref$max === void 0 ? 5 : _ref$max,
    _ref$value = _ref.value,
    value = _ref$value === void 0 ? 0 : _ref$value,
    onChange = _ref.onChange,
    onError = _ref.onError,
    others = _objectWithoutProperties(_ref, _excluded);
  // context
  var context = useContext(Context) || {};
  var locale = context.locale || function (remark) {
    return remark || '';
  };
  function changeHandler(e, argNum) {
    var num = argNum;
    if (num < min) {
      if (onError) {
        onError(e, {
          errMsg: locale("\u4E0D\u80FD\u5C0F\u4E8E".concat(min, "\u9897\u661F"), 'hint_cannot_be_less_than_star', [min]),
          select: num,
          min: min,
          value: min,
          event: e
        });
      }
      num = min;
    }
    if (onChange) onChange(e, num);
  }
  var stars = [];
  for (var i = 1; i <= max; i++) {
    stars.push(i);
  }
  var current = value;
  if (current < min) current = min;
  return /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({
    ref: ref
  }, others), {}, {
    className: "input-star".concat(others.className ? ' ' + others.className : ''),
    children: stars.map(function (index) {
      return /*#__PURE__*/_jsx(Star, {
        onClick: function onClick(e) {
          changeHandler(e, index);
        },
        className: index <= current ? 'active' : ''
      }, index);
    })
  }));
});
export default InputStar;

==> seedsui-react-5.8.10.tgz: package/lib/InputStar/InputStar.js <==
var _excluded = ["min", "max", "value", "onChange", "onError"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useContext } from 'react';
import Star from "./../Star";
import Context from "../Context/instance.js";

/**
 * @deprecated since version 5.2.8
 * 请使用Input.Star
 */
var InputStar = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$min = _ref.min,
    min = _ref$min === void 0 ? 0 : _ref$min,
    _ref$max = _ref.max,
    max = _ref$max === void 0 ? 5 : _ref$max,
    _ref$value = _ref.value,
    value = _ref$value === void 0 ? 0 : _ref$value,
    onChange = _ref.onChange,
    onError = _ref.onError,
    others = _objectWithoutProperties(_ref, _excluded);
  // context
  var context = useContext(Context) || {};
  var locale = context.locale || function (remark) {
    return remark || '';
  };
  function changeHandler(e, argNum) {
    var num = argNum;
    if (num < min) {
      if (onError) {
        onError(e, {
          errMsg: locale("\u4E0D\u80FD\u5C0F\u4E8E".concat(min, "\u9897\u661F"), 'hint_cannot_be_less_than_star', [min]),
          select: num,
          min: min,
          value: min,
          event: e
        });
      }
      num = min;
    }
    if (onChange) onChange(e, num);
  }
  var stars = [];
  for (var i = 1; i <= max; i++) {
    stars.push(i);
  }
  var current = value;
  if (current < min) current = min;
  return /*#__PURE__*/React.createElement("div", _extends({
    ref: ref
  }, others, {
    className: "input-star".concat(others.className ? ' ' + others.className : '')
  }), stars.map(function (index) {
    return /*#__PURE__*/React.createElement(Star, {
      onClick: function onClick(e) {
        changeHandler(e, index);
      },
      key: index,
      className: index <= current ? 'active' : ''
    });
  }));
});
export default InputStar;
